@@ -61,12 +61,33 @@ class ObjectGoal():
     def failed_msg(self, bot, world=None):
         return self.msg()
 
+class DropGoal():
+    def __init__(self, config):
+        self.obj_name = config.get("obj_name")
+        self.x  = config.get("x")
+        self.y = config.get("y")
+        self.val  = config.get('val')
+
+    def is_completed(self, bot, world=None):
+        pos = "{},{}".format(self.x,self.y)
+        obj = world.objects.get(pos, {})
+        val = obj.get(self.obj_name, None)
+        return val == self.val
+
+    def msg(self):
+        return "Expected: Drop object {} at: {},{}".format(self.obj_name, self.x, self.y)
+
+    def failed_msg(self, bot, world=None):
+        return self.msg()
+
+
 
 class_list = {
     "position": PositionGoal,
     "wall": WallGoal,
     "object": ObjectGoal,
-    "reporter": ReporterGoal
+    "reporter": ReporterGoal,
+    "drop": DropGoal
 }
 
 class Goal(object):
