@@ -284,6 +284,18 @@ class WorldModel():
     
     def add_repoter_goal(self, msg):
         self._add_goal("reporter", msg)
+    
+
+    def add_drop_obj_goal(self, x, y, obj_name, val):
+        self._add_goal('drop', {"x": x, "y":y , "val": val, "obj_name": obj_name})
+    
+    def add_pick_obj_goal(self,x, y, obj_name, val):
+        self._add_goal('object', {"x": x, "y":y , "val": val, "obj_name": obj_name})
+    
+    def add_home_goal(self, x, y, image="house"):
+        self._add_goal('position', {"x": x, "y": y})
+        self.add_tile(x, y, "house")
+        
 
     def _add_goal(self, goal_type,  config):        
         goal = Goal.load(goal_type, config)
