@@ -360,7 +360,7 @@ class Robot():
                     if val == picked:
                         self.world.js_call('remove_object', [self.x,self.y])
                     if val > picked:
-                        self.world.js_call('update_object', [self.x, self.y, val - 1])
+                        self.world.js_call('update_object', [self.x, self.y, val - picked])
         else:
             print_error("No Items to Pick.")
             raise RuntimeError("No Items to Pick.")
